@@ -79,3 +79,23 @@ arma::uvec arma_setdiff(arma::uvec x, arma::uvec y){
   }
   return x;
 }
+
+arma::uvec maybe_offset_indices(
+  arma::vec& x,
+  arma::uvec idx_x,
+  const bool& quiet = true
+) {
+  // Adjust the indices of x (i.e., idx_x) depending on whether it seems to be
+  // using R or C++ indices.
+  arma::uvec io_idx_cpp   = arma::find_nonfinite(x);
+  arma::uvec io_idx_input = arma::sort(idx_x);
+  std::string message = "C++ indices detected. Unchanged.";
+  if (arma::any(io_idx_input - io_idx_cpp)) {
+    idx_x -= 1;
+    message = "R indices detected. Shifted.";
+  }
+  if (!quiet) {
+    Rcpp::Rcout << message << std::endl;
+  }
+  return(idx_x);
+}
